# fcmaes
A Python 3 gradient-free optimization library.

- [README](https://github.com/dietmarwo/fast-cma-es/blob/master/README.adoc)
- [Tutorial](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Tutorial.adoc)
- [Multi-Objective](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/MultiObjective.adoc), 
- [MO-DE-NSGAII](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/NSGAII.adoc), 
- [gbea TopTrumps Benchmark](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/TopTrumps.adoc),
- [Pagmo results](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/PAGMO.adoc), 
- [PYKEP Gym Results](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/PYKEP.adoc)
- [Constraints](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Constraints.adoc)
- [Expressions](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/Expressions.adoc)
- [ODE](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/ODE.adoc)
- [MINLP](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/MINLP.adoc)
- [HyperParameters](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/HyperparameterOptimization.adoc)
- [Delayed Update](https://github.com/dietmarwo/fast-cma-es/blob/master/tutorials/DelayedUpdate.adoc)




